camelot.camelot.empty_project.application_admin.MyApplicationAdmin

Package camelot :: Package camelot :: Package empty_project :: Module application_admin :: Class MyApplicationAdmin |
[hide private]
[frames] | no frames]

# Class MyApplicationAdmin

source code

Instance Methods | [hide private]
__init__(self) The main sections to be used in the navigation pane of the application, all entities will be put in such a section, depending on the properties of their EntityAdmin class, a list of tuples of strings and icons [('section', ('Section display name',section_icon))] | source code
Inherited from `view.application_admin.ApplicationAdmin`: `getAbout`, `getActions`, `getEntitiesAndQueriesInSection`, `getEntityAdmin`, `getEntityQuery`, `getIcon`, `getName`, `getSections`, `register` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `view.application_admin.ApplicationAdmin`: `admins`, `sections`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
The main sections to be used in the navigation pane of the application, all entities will be put in such a section, depending on the properties of their EntityAdmin class, a list of tuples of strings and icons [('section', ('Section display name',section_icon))] Overrides: object.__init__ (inherited documentation)